@@ -2,7 +2,7 @@ from acceldata_sdk.errors import TorchSdkException
 from acceldata_sdk.models.pipeline import CreatePipeline, Pipeline, PipelineRun
 from acceldata_sdk.torch_http_client import TorchHttpClient
 from acceldata_sdk.constants import RuleExecutionStatus, FailureStrategy, PolicyType, AssetSourceType, \
-    SDK_MIN_VERSION_SUPPORT, SdkSupportedVersions
+    MIN_TORCH_BACKEND_VERSION_SUPPORTED, SdkSupportedVersions, TorchBuildVersion
 
 from acceldata_sdk.models.rule import RuleResource
 from typing import List
@@ -47,7 +47,7 @@ class TorchClient:
         if self.do_version_check:
             supported_versions = self.get_supported_sdk_versions()
             ver_comparator = SimpleSpec(f'>={supported_versions.minVersion},<={supported_versions.maxVersion}')
-            if Version(SDK_MIN_VERSION_SUPPORT) not in ver_comparator:
+            if Version(MIN_TORCH_BACKEND_VERSION_SUPPORTED) not in ver_comparator:
                 raise Exception(f'Torch supports sdk versions between {supported_versions.minVersion} and '
                                 f'{supported_versions.maxVersion}')
         else:
@@ -57,10 +57,18 @@ class TorchClient:
         """
         Description:
             To get supported sdk versions
-        :return: (SdkSupportedVersions) newly created SdkSupportedVersions class instance
+        :return: (SdkSupportedVersions) SdkSupportedVersions class instance
         """
         return self.client.get_supported_sdk_versions()
 
+    def get_torch_version(self) -> TorchBuildVersion:
+        """
+        Description:
+            To get supported torch version
+        :return: (TorchBuildVersion)
+        """
+        return self.client.get_torch_version()
+
     def create_pipeline(self, pipeline: CreatePipeline) -> Pipeline:
         """
         Description:
@@ -98,14 +106,17 @@ class TorchClient:
         """
         return self.client.get_spans(pipeline_run_id)
 
-    def get_pipeline_run(self, pipeline_run_id: str) -> PipelineRun:
+    def get_pipeline_run(self, pipeline_run_id: str = None, continuation_id: str = None, pipeline_id: str = None) -> PipelineRun:
         """
         Description:
             To get an existing pipeline from torch catalog
-        :param pipeline_run_id: continuation id or run id of the pipeline run
+        :param pipeline_run_id: run id of the pipeline run
+        :param continuation_id: continuation id of the pipeline run
+        :param pipeline_id: id of the pipeline. This is a mandatory parameter when run is being queried using continuation_id
+
         :return:(PipelineRun) pipeline run class instance
         """
-        return self.client.get_pipeline_run(pipeline_run_id)
+        return self.client.get_pipeline_run(pipeline_run_id=pipeline_run_id, continuation_id=continuation_id, pipeline_id=pipeline_id)
 
     def get_pipeline_runs(self, pipeline_id) -> List[PipelineRun]:
         """
@@ -298,6 +309,9 @@ class TorchClient:
         :param incremental: (bool) optional Set it to True if full execution has to be done
         :param failure_strategy: (enum) optional Set it to decide if it should fail at error,
             fail at warning or never fail
+        :param pipeline_run_id: (long) optional Run id of the pipeline run where the policy is being executed. This can
+            be used to link a policy execution id with a particular pipeline run id
+
         """
         return self.client.execute_rule(policy_type, policy_id, sync, incremental, failure_strategy, pipeline_run_id)
 
